import javax.microedition.rms.RecordStore;
import javax.microedition.rms.RecordStoreException;
import javax.microedition.rms.RecordStoreFullException;
import javax.microedition.rms.RecordStoreNotFoundException;



/**
 * @author Gregor Broll, Alex De Luca
 * 
 * This class implements all interactions with the record management system.
 */
public class RecordManager 
{
	private RecordStore historyStore;			//stores the last 5 answers from the server
	
	
	/**
	 * Constructor; sets up the recordstore
	 */
	public RecordManager()
	{		
		try 
		{
			historyStore = RecordStore.openRecordStore("History", true);
			System.out.println("RecordManager(): recordstore opened; next recordID=" + historyStore.getNextRecordID());
		} 
		catch (RecordStoreFullException e) 
		{
			e.printStackTrace();
		} 
		catch (RecordStoreNotFoundException e) 
		{
			e.printStackTrace();
		} 
		catch (RecordStoreException e) 
		{
			e.printStackTrace();
		}
	}	
		
	
    /**
     * Add a record to the recordstore.
     * 
     * @param input
     */
    public void writeRecord(String input)
    {
    	try 
    	{
			historyStore.addRecord(input.getBytes(), 0, input.length());
			System.out.println("writeRecord(): input=" + input + "; next recordID=" + historyStore.getNextRecordID());
		} 
    	catch (RecordStoreFullException e) 
		{
			e.printStackTrace();
		} 
		catch (RecordStoreNotFoundException e) 
		{
			e.printStackTrace();
		} 
		catch (RecordStoreException e) 
		{
			e.printStackTrace();
		}
    }
        
    
    /**
     * This method returns the 5 latest records from the recordstore. Since records can't be stored at 
     * a defined position in the recordstore but are added to its end, this method has to return the last
     * 5 records from the queue.
     * 
     * @return
     */
    public String[] getRecords()
    {
    	String[] records = new String[5];
    	
    	try
    	{
    		int counter = historyStore.getNextRecordID() - 1;			//the position of the last record
        	
        	for(int i=0; i <5; i++)
        	{
        		if(counter-i > 0)
        		{
        			try 
            		{
        				String item = new String(historyStore.getRecord(counter-i));
        				
        				if(item != null)
        					records[i] = item;
        				else
        					records[i] = "";        				
        			} 
            		catch (Exception e) 
            		{
        				e.printStackTrace();    				
        				return records;
        			} 
        		}  
        		else
        			records[i] = "";
        	}
        	
        	System.out.println(historyStore.getNextRecordID());
    	}
    	catch (RecordStoreFullException e) 
		{
			e.printStackTrace();
		} 
		catch (RecordStoreNotFoundException e) 
		{
			e.printStackTrace();
		} 
		catch (RecordStoreException e) 
		{
			e.printStackTrace();
		}
    	
    	return records;
    }  
    
    
    /**
     * Closes the recordstore.
     */
    public void closeRecordStore()
    {
    	try 
    	{
			historyStore.closeRecordStore();			
			System.out.println("RecordManager(): recordstore closed");	
		} 
    	catch (RecordStoreFullException e) 
		{
			e.printStackTrace();
		} 
		catch (RecordStoreNotFoundException e) 
		{
			e.printStackTrace();
		} 
		catch (RecordStoreException e) 
		{
			e.printStackTrace();
		}
    }
}